@@ -19,6 +19,7 @@ import pandas as pd
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import matplotlib.lines as mlines
+from mpl_toolkits.axes_grid1 import make_axes_locatable
 
 from .utils import to_1d_array, get_cmap, _regplot, process_axis
 from .utils import BAR_CMAPS, regplot_combs
@@ -375,6 +376,8 @@ def imshow(
     Parameters
     ----------
         values: 2d array
+            the image/data to show. It must bt 2 dimensional. It can also
+            be dataframe.
         xlabel:  str, optional
         ylabel : str, optional
         title : str, optional
@@ -386,8 +389,10 @@ def imshow(
             whether to draw colorbar or not
         colorbar_orientation : str, optional
             either "vertical" or "horizontal"
-        xticklabels : optional
-        yticklabels :  optional
+        xticklabels : list, optional
+            tick labels for x-axis. For DataFrames, column names are used by default.
+        yticklabels :  list, optional
+            tick labels for y-axis. For DataFrames, index is used by default
         ax : plt.Axes, optional
             if not given, current available axes will be used
         **kwargs : optional
@@ -415,6 +420,13 @@ def imshow(
 
     im = ax.imshow(values, **kwargs)
 
+    if isinstance(values, pd.DataFrame):
+        if not xticklabels:
+            xticklabels = values.columns.to_list()
+        if not yticklabels:
+            yticklabels = values.index.tolist()
+        values = values.values
+
     if annotate:
         annotate_kws = annotate_kws or {"color": "w", "ha":"center", "va":"center"}
         for i in range(values.shape[0]):
@@ -433,8 +445,12 @@ def imshow(
     process_axis(ax, xlabel=xlabel, ylabel=ylabel, title=title)
 
     if colorbar:
+        # https://stackoverflow.com/a/18195921/5982232
+        divider = make_axes_locatable(ax)
+        cax = divider.append_axes("right", size="5%", pad=0.2)
         fig: plt.Figure = plt.gcf()
-        fig.colorbar(im, orientation=colorbar_orientation, pad=0.2)
+        fig.colorbar(im, orientation=colorbar_orientation, pad=0.2, cax=cax)
+
 
     if show:
         plt.show()
